@@ -29,27 +29,27 @@ calling.function <- function(parentheses=TRUE) {
 check.mcmc.parameters <- function(burnin, mcmc, thin) {
   
   if(mcmc %% thin != 0) {
-    cat("Error: MCMC iterations not evenly divisible by thinning interval.\n")
+    message("Error: MCMC iterations not evenly divisible by thinning interval.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
   if(mcmc <= 0) {
-    cat("Error: MCMC iterations must be strictly positive.\n")
+    message("Error: MCMC iterations must be strictly positive.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE) 
   }
   if(burnin < 0) {
-    cat("Error: Burnin iterations must be positive.\n")
+    message("Error: Burnin iterations must be positive.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
   if(((burnin+mcmc) %% 10 != 0) || (burnin+mcmc)<100) {
-    cat("Error: Value 'burnin+mcmc' should be divisible by 10 and >= 100.\n")
+    message("Error: Value 'burnin+mcmc' should be divisible by 10 and >= 100.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
   if(thin < 1) {
-    cat("Error: Thinning interval must be superior or equal to 1.\n")
+    message("Error: Thinning interval must be superior or equal to 1.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -64,7 +64,7 @@ check.mcmc.parameters <- function(burnin, mcmc, thin) {
 
 check.verbose <- function (verbose) {
   if (!(verbose %in% c(0,1))) {
-    cat("Error: verbose must take value 0 or 1.\n")
+    message("Error: verbose must take value 0 or 1.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -79,65 +79,65 @@ check.verbose <- function (verbose) {
 
 check.Y.poisson <- function (Y) {
   if(!is.numeric(Y)) {
-    cat("Error: 'counts' must be a vector of numeric values.\n")
+    message("Error: 'counts' must be a vector of numeric values.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
   if (sum(is.na(Y))>0) {
-    cat("Error: 'counts' must not contain missing values.\n")
+    message("Error: 'counts' must not contain missing values.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
   if (sum(Y<0 | Y%%1!=0)>0) {
-    cat("Error: 'counts' must be a vector of positive integers.\n")
+    message("Error: 'counts' must be a vector of positive integers.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
   return(0)
 }
 
-check.T.binomial <- function (T, nobs) { # = This version of the function assumes T>0
-  if(length(T)!=nobs) {
-    cat("Error: 'trials' must have the same length as the response variable.\n")
+check.N.binomial <- function (N, nobs) { # = This version of the function assumes N>0
+  if(length(N)!=nobs) {
+    message("Error: 'trials' must have the same length as the response variable.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
-  if(!is.numeric(T)) {
-    cat("Error: 'trials' must be a vector of numeric values.\n")
+  if(!is.numeric(N)) {
+    message("Error: 'trials' must be a vector of numeric values.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
-  if (sum(is.na(T))>0) {
-    cat("Error: 'trials' must not contain missing values.\n")
+  if (sum(is.na(N))>0) {
+    message("Error: 'trials' must not contain missing values.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
-  if (sum(T<=0 | T%%1!=0)>0) {
-    cat("Error: 'trials' must be a vector of integers superior to zero.\n")
+  if (sum(N<=0 | N%%1!=0)>0) {
+    message("Error: 'trials' must be a vector of integers superior to zero.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
   return(0)
 }
 
-check.Y.binomial <- function (Y,T) {
+check.Y.binomial <- function (Y,N) {
   if(!is.numeric(Y)) {
-    cat("Error: 'presences' must be a vector or a matrix of numeric values.\n")
+    message("Error: 'presences' must be a vector or a matrix of numeric values.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
   if (sum(is.na(Y))>0) {
-    cat("Error: 'presences' must not contain missing values.\n")
+    message("Error: 'presences' must not contain missing values.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
   if (sum(Y<0 | Y%%1!=0)>0) {
-    cat("Error: 'presences' must be a vector of positive integers.\n")
+    message("Error: 'presences' must be a vector of positive integers.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   } 
-  if (sum(Y>T)>0) {
-    cat("Error: 'presences' must be less than or equal to 'trials'.\n")
+  if (sum(Y>N)>0) {
+    message("Error: 'presences' must be less than or equal to 'trials'.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -146,22 +146,22 @@ check.Y.binomial <- function (Y,T) {
 
 # check.U <- function (U,nobs) {
 #   if(length(U)!=nobs) {
-#     cat("Error: 'alteration' must have the same length as the response variable.\n")
+#     message("Error: 'alteration' must have the same length as the response variable.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if(!is.numeric(U)) {
-#     cat("Error: 'alteration' must be a vector of numeric values.\n")
+#     message("Error: 'alteration' must be a vector of numeric values.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if (sum(is.na(U))>0) {
-#     cat("Error: 'alteration' must not contain missing values.\n")
+#     message("Error: 'alteration' must not contain missing values.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if (!all(U>=0 && U<=1)) {
-#     cat("Error: 'alteration' must be in the interval [0,1].\n")
+#     message("Error: 'alteration' must be in the interval [0,1].\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
@@ -170,17 +170,17 @@ check.Y.binomial <- function (Y,T) {
 
 check.X <- function (X,n) {
   if(!is.numeric(c(X))) {
-    cat("Error: 'suitability' only accept vectors of numeric values.\n")
+    message("Error: 'suitability' only accept vectors of numeric values.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
   if (sum(is.na(c(X)))>0) {
-    cat("Error: 'suitability' do not accept vectors with missing values.\n")
+    message("Error: 'suitability' do not accept vectors with missing values.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
   if (dim(X)[1]!=n) {
-    cat("Error: Incorrect vector length for the 'suitability' argument.\n")
+    message("Error: Incorrect vector length for the 'suitability' argument.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -189,12 +189,12 @@ check.X <- function (X,n) {
 
 check.Y.gaussian <- function(Y) {
   if(!is.numeric(Y)) {
-    cat("Error: 'response_data' must be a vector or a matrix of numeric values.\n")
+    message("Error: 'response_data' must be a vector or a matrix of numeric values.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
   if (sum(is.na(Y))>0) {
-    cat("Error: 'response_data' must not contain missing values.\n")
+    message("Error: 'response_data' must not contain missing values.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -202,17 +202,17 @@ check.Y.gaussian <- function(Y) {
 }
 # check.W <- function (W,n) {
 #   if(!is.numeric(c(W))) {
-#     cat("Error: 'observability' only accept vectors of numeric values.\n")
+#     message("Error: 'observability' only accept vectors of numeric values.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if (sum(is.na(c(W)))>0) {
-#     cat("Error: 'observability' do not accept vectors with missing values.\n")
+#     message("Error: 'observability' do not accept vectors with missing values.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if (dim(W)[1]!=n) {
-#     cat("Error: Incorrect vector length for the 'observability' argument.\n")
+#     message("Error: Incorrect vector length for the 'observability' argument.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
@@ -222,58 +222,58 @@ check.Y.gaussian <- function(Y) {
 # check.neighbors <- function (n.neighbors,ncell,neighbors) {
 #   # Length of n.neighbors=ncell
 #   if(length(n.neighbors)!=ncell) {
-#     cat("Error: 'n.neighbors' must have a length equal to the number of cells.\n")
+#     message("Error: 'n.neighbors' must have a length equal to the number of cells.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   # Numeric values
 #   if(!is.numeric(neighbors)) {
-#     cat("Error: 'neighbors' must be a vector of numeric values.\n")
+#     message("Error: 'neighbors' must be a vector of numeric values.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if(!is.numeric(n.neighbors)) {
-#     cat("Error: 'n.neighbors' must be a vector of numeric values.\n")
+#     message("Error: 'n.neighbors' must be a vector of numeric values.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   # NA
 #   if (sum(is.na(neighbors))>0) {
-#     cat("Error: 'neighbors' must not contain missing values.\n")
+#     message("Error: 'neighbors' must not contain missing values.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if (sum(is.na(n.neighbors))>0) {
-#     cat("Error: 'n.neighbors' must not contain missing values.\n")
+#     message("Error: 'n.neighbors' must not contain missing values.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   # Positive integer
 #   if (sum(neighbors<=0 | neighbors%%1!=0)>0) {
-#     cat("Error: 'neighbors' must be a vector of integers superior to zero.\n")
+#     message("Error: 'neighbors' must be a vector of integers superior to zero.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if (sum(n.neighbors<=0 | n.neighbors%%1!=0)>0) {
-#     cat("Error: 'n.neighbors' must be a vector of integers superior to zero.\n")
+#     message("Error: 'n.neighbors' must be a vector of integers superior to zero.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   # Number of neighbors inferior to ncell-1
 #   if (!all(n.neighbors < (ncell-1))) {
-#     cat("Error: 'n.neighbors' must not contain values superior to ncell-1.\n")
+#     message("Error: 'n.neighbors' must not contain values superior to ncell-1.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   # Number of neighbors and length of neighbors
 #   if (sum(n.neighbors)!=length(neighbors)) {
-#     cat("Error: 'neighbors' must be a vector of length equal to sum(n.neighbors).\n")
+#     message("Error: 'neighbors' must be a vector of length equal to sum(n.neighbors).\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   # Check values in neighbors
 #   if (sum(!(neighbors %in% c(1:ncell)))>0) {
-#     cat("Error: 'neighbors' must be a vector of integers between 1 and ncell.\n")
+#     message("Error: 'neighbors' must be a vector of integers between 1 and ncell.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
@@ -283,22 +283,22 @@ check.Y.gaussian <- function(Y) {
 # 
 # check.sites <- function (sites,nobs) {
 #   if(length(sites)!=nobs) {
-#     cat("Error: 'sites' must have the same length as the response variable.\n")
+#     message("Error: 'sites' must have the same length as the response variable.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if(!is.numeric(sites)) {
-#     cat("Error: 'sites' must be a vector of numeric values.\n")
+#     message("Error: 'sites' must be a vector of numeric values.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if (sum(is.na(sites))>0) {
-#     cat("Error: 'sites' must not contain missing values.\n")
+#     message("Error: 'sites' must not contain missing values.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if (sum(sites<=0 | sites%%1!=0)>0) {
-#     cat("Error: 'sites' must be a vector of integers superior to zero.\n")
+#     message("Error: 'sites' must be a vector of integers superior to zero.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
@@ -307,22 +307,22 @@ check.Y.gaussian <- function(Y) {
 # 
 # check.cells <- function (cells,nsite) {
 #   if(length(cells)!=nsite) {
-#     cat("Error: 'spatial.entity' must be of length equals to the number of sites.\n")
+#     message("Error: 'spatial.entity' must be of length equals to the number of sites.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if(!is.numeric(cells)) {
-#     cat("Error: 'spatial.entity' must be a vector of numeric values.\n")
+#     message("Error: 'spatial.entity' must be a vector of numeric values.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if (sum(is.na(cells))>0) {
-#     cat("Error: 'spatial.entity' must not contain missing values.\n")
+#     message("Error: 'spatial.entity' must not contain missing values.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if (sum(cells<=0 | cells%%1!=0)>0) {
-#     cat("Error: 'spatial.entity' must be a vector of integers superior to zero.\n")
+#     message("Error: 'spatial.entity' must be a vector of integers superior to zero.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
@@ -331,22 +331,22 @@ check.Y.gaussian <- function(Y) {
 # 
 # check.cells.pred <- function (cells.pred,npred) {
 #   if(length(cells.pred)!=npred) {
-#     cat("Error: 'spatial.entity.pred' must be of length equals to the number of predictions.\n")
+#     message("Error: 'spatial.entity.pred' must be of length equals to the number of predictions.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if(!is.numeric(cells.pred)) {
-#     cat("Error: 'spatial.entity.pred' must be a vector of numeric values.\n")
+#     message("Error: 'spatial.entity.pred' must be a vector of numeric values.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if (sum(is.na(cells.pred))>0) {
-#     cat("Error: 'spatial.entity.pred' must not contain missing values.\n")
+#     message("Error: 'spatial.entity.pred' must not contain missing values.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if (sum(cells.pred<=0 | cells.pred%%1!=0)>0) {
-#     cat("Error: 'spatial.entity.pred' must be a vector of integers superior to zero.\n")
+#     message("Error: 'spatial.entity.pred' must be a vector of integers superior to zero.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
@@ -362,17 +362,17 @@ check.Y.gaussian <- function(Y) {
 #
 # check.Vrho.start <- function (Vrho.start) {
 #   if (length(Vrho.start)!=1) {
-#     cat("Error: Vrho.start should be a scalar.\n")
+#     message("Error: Vrho.start should be a scalar.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if (!is.numeric(Vrho.start)) {
-#     cat("Error: Vrho.start should be a numeric.\n")
+#     message("Error: Vrho.start should be a numeric.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if (Vrho.start<=0) {
-#     cat("Error: Vrho.start should be strictly positive.\n")
+#     message("Error: Vrho.start should be strictly positive.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
@@ -387,7 +387,7 @@ check.Y.gaussian <- function(Y) {
 
 # check.Vbeta <- function(Vbeta, np) {
 #   if (!all(Vbeta>0)) {
-#     cat("Error: Vbeta should be strictly positive.\n")
+#     message("Error: Vbeta should be strictly positive.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
@@ -395,7 +395,7 @@ check.Y.gaussian <- function(Y) {
 #     Vbeta <- rep(Vbeta,np) 
 #   }
 #   else if (length(Vbeta)!=np) {
-#     cat("Error: Vbeta not conformable.\n")
+#     message("Error: Vbeta not conformable.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
@@ -407,7 +407,7 @@ check.Y.gaussian <- function(Y) {
 #     mugamma <- rep(mugamma,nq) 
 #   }
 #   else if (length(mugamma)!=nq) {
-#     cat("Error: mugamma not conformable.\n")
+#     message("Error: mugamma not conformable.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
@@ -416,7 +416,7 @@ check.Y.gaussian <- function(Y) {
 
 # check.Vgamma <- function(Vgamma, nq) {
 #   if (!all(Vgamma>0)) {
-#     cat("Error: Vgamma should be strictly positive.\n")
+#     message("Error: Vgamma should be strictly positive.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
@@ -424,7 +424,7 @@ check.Y.gaussian <- function(Y) {
 #     Vgamma <- rep(Vgamma,nq) 
 #   }
 #   else if (length(Vgamma)!=nq) {
-#     cat("Error: Vgamma not conformable.\n")
+#     message("Error: Vgamma not conformable.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
@@ -434,12 +434,12 @@ check.Y.gaussian <- function(Y) {
 # check.ig.prior <- function(nu, delta) {
 #   
 #   if(nu <= 0) {
-#     cat("Error: in IG(nu,delta) prior, nu less than or equal to zero.\n")
+#     message("Error: in IG(nu,delta) prior, nu less than or equal to zero.\n")
 #     stop("Please respecify and call ", calling.function(), " again.\n",
 #          call.=FALSE)
 #   }
 #   if(delta <= 0) {
-#     cat("Error: in IG(nu,delta) prior, delta less than or equal to zero.\n")
+#     message("Error: in IG(nu,delta) prior, delta less than or equal to zero.\n")
 #     stop("Please respecify and call ", calling.function(), " again.\n",
 #          call.=FALSE)    
 #   }
@@ -448,17 +448,17 @@ check.Y.gaussian <- function(Y) {
 # 
 # check.Vrho.max <- function (Vrho.max) {
 #   if (length(Vrho.max)!=1) {
-#     cat("Error: Vrho.max should be a scalar.\n")
+#     message("Error: Vrho.max should be a scalar.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if (!is.numeric(Vrho.max)) {
-#     cat("Error: Vrho.max should be a numeric.\n")
+#     message("Error: Vrho.max should be a numeric.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
 #   if (Vrho.max<=0) {
-#     cat("Error: Vrho.max should be strictly positive.\n")
+#     message("Error: Vrho.max should be strictly positive.\n")
 #     stop("Please respecify and call ", calling.function(), " again.",
 #          call.=FALSE)
 #   }
@@ -477,7 +477,7 @@ check.Y.gaussian <- function(Y) {
 #   }
 #   else {
 #     priorVrho <- -1.0
-#     cat("priorVrho has been set to \"1/Gamma\" \n")
+#     message("priorVrho has been set to \"1/Gamma\" \n")
 #   }
 #   return(priorVrho)
 # }
@@ -500,7 +500,7 @@ form.beta.start <- function (beta.start, np) {
     beta.start <- rep(beta.start[1],np) 
   }
   else if(length(beta.start)!=np) {
-    cat("Error: beta.start not conformable.\n")
+    message("Error: beta.start not conformable.\n")
     stop("Please respecify and call ", calling.function(), " again.\n",
          call.=FALSE)
   }
@@ -515,7 +515,7 @@ form.gamma.start <- function (gamma.start,nq) {
     gamma.start <- rep(gamma.start[1],nq)
   }
   else if(length(gamma.start)!=nq) {
-    cat("Error: gamma.start not conformable.\n")
+    message("Error: gamma.start not conformable.\n")
     stop("Please respecify and call ", calling.function(), " again.\n",
          call.=FALSE)
   }
@@ -525,7 +525,7 @@ form.gamma.start <- function (gamma.start,nq) {
 
 form.gamma.start.mat <- function(gamma.start,nt,np){
   if(!all(!is.na(gamma.start))){
-    cat("Error: gamma_start must no contain missing values.\n")
+    message("Error: gamma_start must no contain missing values.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -538,7 +538,7 @@ form.gamma.start.mat <- function(gamma.start,nt,np){
         gamma.start.mat <- matrix(gamma.start,nt,np, byrow=TRUE) 
       }
       else if(sum(c(np,nt,np*nt,1)==length(gamma.start))==0){
-        cat("Error: gamma_start not conformable, you can specify a vector of length np=", np,
+        message("Error: gamma_start not conformable, you can specify a vector of length np=", np,
             "(number of covariates plus intercept), nt=", nt,
             "(number of traits plus intercept) or np.nt=", np*nt, "to fill matrix gamma_start.\n")
         stop("Please respecify and call ", calling.function(), " again.",
@@ -550,7 +550,7 @@ form.gamma.start.mat <- function(gamma.start,nt,np){
     gamma.start.mat <- gamma.start
   }
   else if(sum(dim(gamma.start)==c(nt,np))!=2){
-    cat("Error: gamma_start not conformable, should form a matrix of size (number of traits plus intercept) nt x np (number of covariates plus intercept) :"
+    message("Error: gamma_start not conformable, should form a matrix of size (number of traits plus intercept) nt x np (number of covariates plus intercept) :"
         , nt," x", np,". \n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
@@ -664,7 +664,7 @@ form.W.start.sp <- function (W.start, nsite, n_latent) {
 
 check.mugamma.mat <- function(mugamma,nt,np){
   if(!all(!is.na(mugamma))){
-    cat("Error: mu_gamma must no contain missing values.\n")
+    message("Error: mu_gamma must no contain missing values.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -677,7 +677,7 @@ check.mugamma.mat <- function(mugamma,nt,np){
         mugamma.mat <- matrix(mugamma,nt,np, byrow=TRUE) 
       }
       else if(sum(c(np,nt,np*nt,1)==length(mugamma))==0){
-        cat("Error: mu_gamma not conformable, you can specify a vector of length np=", np,
+        message("Error: mu_gamma not conformable, you can specify a vector of length np=", np,
             "(number of covariates plus intercept), nt=", nt,
             "(number of traits plus intercept) or np.nt=", np*nt, "to fill matrix mu_gamma.\n")
         stop("Please respecify and call ", calling.function(), " again.",
@@ -689,7 +689,7 @@ check.mugamma.mat <- function(mugamma,nt,np){
     mugamma.mat <- mugamma
   }
   else if(sum(dim(mugamma)==c(nt,np))!=2){
-    cat("Error: mu_gamma not conformable, should form a matrix of size (number of traits plus intercept) nt x np (number of covariates plus intercept) :"
+    message("Error: mu_gamma not conformable, should form a matrix of size (number of traits plus intercept) nt x np (number of covariates plus intercept) :"
         , nt," x", np,". \n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
@@ -699,12 +699,12 @@ check.mugamma.mat <- function(mugamma,nt,np){
 
 check.Vgamma.mat <- function(Vgamma,nt,np){
   if(!all(!is.na(Vgamma))){
-    cat("Error: V_gamma must no contain missing values.\n")
+    message("Error: V_gamma must no contain missing values.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
   if (!all(Vgamma>=0)) {
-    cat("Error: V_gamma should be positive.\n")
+    message("Error: V_gamma should be positive.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -717,7 +717,7 @@ check.Vgamma.mat <- function(Vgamma,nt,np){
         Vgamma.mat <- matrix(Vgamma,nt,np, byrow=TRUE)
       }
       else if(sum(c(np,nt,np*nt,1)==length(Vgamma))==0){
-        cat("Error: V_gamma not conformable, you can specify a vector of length np=", np,
+        message("Error: V_gamma not conformable, you can specify a vector of length np=", np,
             "(number of covariates plus intercept), nt=", nt,
             "(number of traits plus intercept) or nt.np=", nt*np, "to fill matrix V_gamma.\n")
         stop("Please respecify and call ", calling.function(), " again.",
@@ -729,7 +729,7 @@ check.Vgamma.mat <- function(Vgamma,nt,np){
     Vgamma.mat <- Vgamma
   }
   else if(sum(dim(Vgamma)==c(nt,np))!=2){
-    cat("Error: V_gamma not conformable, should form a matrix of size (number of traits plus intercept) nt x np (number of covariates plus intercept) :",
+    message("Error: V_gamma not conformable, should form a matrix of size (number of traits plus intercept) nt x np (number of covariates plus intercept) :",
         nt,"x", np,". \n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
@@ -747,7 +747,7 @@ check.mubeta <- function(mubeta, np){
     }
   }
   else if (length(mubeta)!=np) {
-    cat("Error: mubeta not conformable.\n")
+    message("Error: mubeta not conformable.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -756,14 +756,14 @@ check.mubeta <- function(mubeta, np){
 
 check.Vbeta <- function(Vbeta, np) {
   if (!all(Vbeta>0) && sum(is.na(Vbeta))!=0) {
-    cat("Error: Vbeta should be strictly positive.\n")
+    message("Error: Vbeta should be strictly positive.\n")
     stop("Please respecify and call ", calling.function(), " again.", call.=FALSE)
   }
   if (is.scalar(Vbeta)) {
     Vbeta <- rep(Vbeta,np)
   }
   else if (length(Vbeta)!=np){
-    cat("Error: Vbeta not conformable.\n")
+    message("Error: Vbeta not conformable.\n")
     stop("Please respecify and call ", calling.function(), " again.",call.=FALSE)
   }
   if(!is.null(dim(Vbeta)) && length(Vbeta)==np){
@@ -775,14 +775,14 @@ check.Vbeta <- function(Vbeta, np) {
 check.Vbeta.mat <- function(Vbeta, np) {
   if (sum(dim(Vbeta)==c(np,np))==2){
     if (!all(diag(Vbeta)>0) && sum(is.na(Vbeta))!=0) {
-      cat("Error: V_beta should be strictly positive on diagonal.\n")
+      message("Error: V_beta should be strictly positive on diagonal.\n")
       stop("Please respecify and call ", calling.function(), " again.",
            call.=FALSE)
     }
     Vbeta.mat <- Vbeta
   }
   else if (!all(Vbeta>0) && sum(is.na(Vbeta))!=0) {
-    cat("Error: V_beta should be strictly positive on diagonal.\n")
+    message("Error: V_beta should be strictly positive on diagonal.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -796,14 +796,14 @@ check.Vbeta.mat <- function(Vbeta, np) {
         Vbeta.mat <- matrix(0,np,np)
         diag(Vbeta.mat) <- Vbeta 
       } else{
-        cat("Error: V_beta not conformable, you must specify a ", np,"-length vector to fill the diagonal of the square matrix", np,"x",np,".\n")
+        message("Error: V_beta not conformable, you must specify a ", np,"-length vector to fill the diagonal of the square matrix", np,"x",np,".\n")
         stop("Please respecify and call ", calling.function(), " again.",
              call.=FALSE) 
       }
     }
   }
   else if (sum(dim(Vbeta) != c(np, np)) > 0) {
-    cat("Error: V_beta not conformable, should form a square matrix", np,"x",np,".\n")
+    message("Error: V_beta not conformable, should form a square matrix", np,"x",np,".\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -815,7 +815,7 @@ check.mub <- function(mub, nd) {
     mub <- rep(mub,nd) 
   }
   else if (length(mub)!=nd) {
-    cat("Error: mu_b not conformable.\n")
+    message("Error: mu_b not conformable.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -824,7 +824,7 @@ check.mub <- function(mub, nd) {
 
 check.Vb.mat <- function(Vb, nd) {
   if (!all(Vb>0)) {
-    cat("Error: V_b should be strictly positive.\n")
+    message("Error: V_b should be strictly positive.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -832,7 +832,7 @@ check.Vb.mat <- function(Vb, nd) {
     Vb <- diag(rep(Vb,nd))
   }
   else if (sum(dim(Vb) != c(nd, nd)) > 0) {
-    cat("Error: V_b not conformable.\n")
+    message("Error: V_b not conformable.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -849,7 +849,7 @@ check.mulambda <- function(mulambda, n_latent) {
     }
   }
   else if (length(mulambda)!=n_latent) {
-    cat("Error: mulambda not conformable.\n")
+    message("Error: mulambda not conformable.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -860,14 +860,14 @@ check.Vlambda.mat <- function(Vlambda, n_latent) {
   
   if (sum(dim(Vlambda)==c(n_latent,n_latent))==2) {
     if (!all(diag(Vlambda)>0) && sum(is.na(Vlambda))!=0) {
-      cat("Error: V_lambda should be strictly positive on diagonal.\n")
+      message("Error: V_lambda should be strictly positive on diagonal.\n")
       stop("Please respecify and call ", calling.function(), " again.",
            call.=FALSE)
     }
     Vlambda.mat <- Vlambda
   }
   else if (!all(Vlambda>0) && sum(is.na(Vlambda))!=0) {
-    cat("Error: Vlambda should be strictly positive.\n")
+    message("Error: Vlambda should be strictly positive.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -884,7 +884,7 @@ check.Vlambda.mat <- function(Vlambda, n_latent) {
     }
   }
   else if (sum(dim(Vlambda) != c(n_latent, n_latent)) > 0) {
-    cat("Error: Vlambda not conformable.\n")
+    message("Error: Vlambda not conformable.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -893,14 +893,14 @@ check.Vlambda.mat <- function(Vlambda, n_latent) {
 
 check.Vlambda <- function(Vlambda, n_latent) {
   if (!all(Vlambda>0) && sum(is.na(Vlambda))!=0) {
-    cat("Error: Vlambda should be strictly positive.\n")
+    message("Error: Vlambda should be strictly positive.\n")
     stop("Please respecify and call ", calling.function(), " again.", call.=FALSE)
   }
   if (is.scalar(Vlambda)) {
     Vlambda <- rep(Vlambda,n_latent)
   }
   else if (length(Vlambda)!=n_latent){
-    cat("Error: Vlambda not conformable.\n")
+    message("Error: Vlambda not conformable.\n")
     stop("Please respecify and call ", calling.function(), " again.",call.=FALSE)
   }
   if(!is.null(dim(Vlambda)) && length(Vlambda)==n_latent){
@@ -911,12 +911,12 @@ check.Vlambda <- function(Vlambda, n_latent) {
 
 check.Valpha <- function(V_alpha_start) {
   if (!(V_alpha_start>0)) {
-    cat("Error: V_alpha_start should be strictly positive.\n")
+    message("Error: V_alpha_start should be strictly positive.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
   else if (!is.null(dim(V_alpha_start))) {
-    cat("Error: V_alpha_start not conformable.\n")
+    message("Error: V_alpha_start not conformable.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
@@ -925,12 +925,12 @@ check.Valpha <- function(V_alpha_start) {
 
 check.V <- function(V_start) {
   if (!(V_start>0)) {
-    cat("Error: The variance of residuals V should be strictly positive.\n")
+    message("Error: The variance of residuals V should be strictly positive.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
   else if (!is.null(dim(V_start))) {
-    cat("Error: V_start not conformable.\n")
+    message("Error: V_start not conformable.\n")
     stop("Please respecify and call ", calling.function(), " again.",
          call.=FALSE)
   }
